# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tls/v3/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/tls/v3/common.proto',
  package='envoy.extensions.transport_sockets.tls.v3',
  syntax='proto3',
  serialized_options=b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\013CommonProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6envoy/extensions/transport_sockets/tls/v3/common.proto\x12)envoy.extensions.transport_sockets.tls.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xa0\x03\n\rTlsParameters\x12t\n\x1ctls_minimum_protocol_version\x18\x01 \x01(\x0e\x32\x44.envoy.extensions.transport_sockets.tls.v3.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12t\n\x1ctls_maximum_protocol_version\x18\x02 \x01(\x0e\x32\x44.envoy.extensions.transport_sockets.tls.v3.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcipher_suites\x18\x03 \x03(\t\x12\x13\n\x0b\x65\x63\x64h_curves\x18\x04 \x03(\t\"O\n\x0bTlsProtocol\x12\x0c\n\x08TLS_AUTO\x10\x00\x12\x0b\n\x07TLSv1_0\x10\x01\x12\x0b\n\x07TLSv1_1\x10\x02\x12\x0b\n\x07TLSv1_2\x10\x03\x12\x0b\n\x07TLSv1_3\x10\x04:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.api.v2.auth.TlsParameters\"\xb4\x01\n\x12PrivateKeyProvider\x12\x1e\n\rprovider_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x34\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x06\xb8\xb7\x8b\xa4\x02\x01H\x00:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.auth.PrivateKeyProviderB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\"\x90\x04\n\x0eTlsCertificate\x12;\n\x11\x63\x65rtificate_chain\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12=\n\x0bprivate_key\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x41\n\x11watched_directory\x18\x07 \x01(\x0b\x32&.envoy.config.core.v3.WatchedDirectory\x12[\n\x14private_key_provider\x18\x06 \x01(\x0b\x32=.envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider\x12:\n\x08password\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x35\n\x0bocsp_staple\x18\x04 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12\x46\n\x1csigned_certificate_timestamp\x18\x05 \x03(\x0b\x32 .envoy.config.core.v3.DataSource:\'\x9a\xc5\x88\x1e\"\n envoy.api.v2.auth.TlsCertificate\"\x85\x01\n\x14TlsSessionTicketKeys\x12>\n\x04keys\x18\x01 \x03(\x0b\x32 .envoy.config.core.v3.DataSourceB\x0e\xfa\x42\x05\x92\x01\x02\x08\x01\xb8\xb7\x8b\xa4\x02\x01:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.auth.TlsSessionTicketKeys\"\x8d\x06\n\x1c\x43\x65rtificateValidationContext\x12\x34\n\ntrusted_ca\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12\x41\n\x11watched_directory\x18\x0b \x01(\x0b\x32&.envoy.config.core.v3.WatchedDirectory\x12/\n\x17verify_certificate_spki\x18\x03 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04\x10,(,\x12/\n\x17verify_certificate_hash\x18\x02 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04\x10@(_\x12\x45\n\x17match_subject_alt_names\x18\t \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12H\n$require_signed_certificate_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\x03\x63rl\x18\x07 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12!\n\x19\x61llow_expired_certificate\x18\x08 \x01(\x08\x12\x8a\x01\n\x18trust_chain_verification\x18\n \x01(\x0e\x32^.envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.TrustChainVerificationB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"F\n\x16TrustChainVerification\x12\x16\n\x12VERIFY_TRUST_CHAIN\x10\x00\x12\x14\n\x10\x41\x43\x43\x45PT_UNTRUSTED\x10\x01:5\x9a\xc5\x88\x1e\x30\n.envoy.api.v2.auth.CertificateValidationContextJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06R\x17verify_subject_alt_nameBP\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\x0b\x43ommonProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_TLSPARAMETERS_TLSPROTOCOL = _descriptor.EnumDescriptor(
  name='TlsProtocol',
  full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters.TlsProtocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TLS_AUTO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_0', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_1', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_2', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_3', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=652,
  serialized_end=731,
)
_sym_db.RegisterEnumDescriptor(_TLSPARAMETERS_TLSPROTOCOL)

_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION = _descriptor.EnumDescriptor(
  name='TrustChainVerification',
  full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.TrustChainVerification',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERIFY_TRUST_CHAIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPT_UNTRUSTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2243,
  serialized_end=2313,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION)


_TLSPARAMETERS = _descriptor.Descriptor(
  name='TlsParameters',
  full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tls_minimum_protocol_version', full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters.tls_minimum_protocol_version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_maximum_protocol_version', full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters.tls_maximum_protocol_version', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cipher_suites', full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters.cipher_suites', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecdh_curves', full_name='envoy.extensions.transport_sockets.tls.v3.TlsParameters.ecdh_curves', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TLSPARAMETERS_TLSPROTOCOL,
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.api.v2.auth.TlsParameters',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=771,
)


_PRIVATEKEYPROVIDER = _descriptor.Descriptor(
  name='PrivateKeyProvider',
  full_name='envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.api.v2.auth.PrivateKeyProvider',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=774,
  serialized_end=954,
)


_TLSCERTIFICATE = _descriptor.Descriptor(
  name='TlsCertificate',
  full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_chain', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.certificate_chain', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.private_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watched_directory', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.watched_directory', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key_provider', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.private_key_provider', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.password', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocsp_staple', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.ocsp_staple', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_certificate_timestamp', full_name='envoy.extensions.transport_sockets.tls.v3.TlsCertificate.signed_certificate_timestamp', index=6,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\"\n envoy.api.v2.auth.TlsCertificate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=957,
  serialized_end=1485,
)


_TLSSESSIONTICKETKEYS = _descriptor.Descriptor(
  name='TlsSessionTicketKeys',
  full_name='envoy.extensions.transport_sockets.tls.v3.TlsSessionTicketKeys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='envoy.extensions.transport_sockets.tls.v3.TlsSessionTicketKeys.keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.api.v2.auth.TlsSessionTicketKeys',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1488,
  serialized_end=1621,
)


_CERTIFICATEVALIDATIONCONTEXT = _descriptor.Descriptor(
  name='CertificateValidationContext',
  full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trusted_ca', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.trusted_ca', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watched_directory', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.watched_directory', index=1,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verify_certificate_spki', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.verify_certificate_spki', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\222\001\010\"\006r\004\020,(,', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verify_certificate_hash', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.verify_certificate_hash', index=3,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\222\001\010\"\006r\004\020@(_', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_subject_alt_names', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.match_subject_alt_names', index=4,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_signed_certificate_timestamp', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.require_signed_certificate_timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crl', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.crl', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_expired_certificate', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.allow_expired_certificate', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trust_chain_verification', full_name='envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.trust_chain_verification', index=8,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION,
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.api.v2.auth.CertificateValidationContext',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1624,
  serialized_end=2405,
)

_TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version'].enum_type = _TLSPARAMETERS_TLSPROTOCOL
_TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version'].enum_type = _TLSPARAMETERS_TLSPROTOCOL
_TLSPARAMETERS_TLSPROTOCOL.containing_type = _TLSPARAMETERS
_PRIVATEKEYPROVIDER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PRIVATEKEYPROVIDER.oneofs_by_name['config_type'].fields.append(
  _PRIVATEKEYPROVIDER.fields_by_name['typed_config'])
_PRIVATEKEYPROVIDER.fields_by_name['typed_config'].containing_oneof = _PRIVATEKEYPROVIDER.oneofs_by_name['config_type']
_TLSCERTIFICATE.fields_by_name['certificate_chain'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['private_key'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['watched_directory'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._WATCHEDDIRECTORY
_TLSCERTIFICATE.fields_by_name['private_key_provider'].message_type = _PRIVATEKEYPROVIDER
_TLSCERTIFICATE.fields_by_name['password'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['ocsp_staple'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['signed_certificate_timestamp'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_TLSSESSIONTICKETKEYS.fields_by_name['keys'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trusted_ca'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['watched_directory'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._WATCHEDDIRECTORY
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['match_subject_alt_names'].message_type = envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2._STRINGMATCHER
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['require_signed_certificate_timestamp'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['crl'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification'].enum_type = _CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION
_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION.containing_type = _CERTIFICATEVALIDATIONCONTEXT
DESCRIPTOR.message_types_by_name['TlsParameters'] = _TLSPARAMETERS
DESCRIPTOR.message_types_by_name['PrivateKeyProvider'] = _PRIVATEKEYPROVIDER
DESCRIPTOR.message_types_by_name['TlsCertificate'] = _TLSCERTIFICATE
DESCRIPTOR.message_types_by_name['TlsSessionTicketKeys'] = _TLSSESSIONTICKETKEYS
DESCRIPTOR.message_types_by_name['CertificateValidationContext'] = _CERTIFICATEVALIDATIONCONTEXT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TlsParameters = _reflection.GeneratedProtocolMessageType('TlsParameters', (_message.Message,), {
  'DESCRIPTOR' : _TLSPARAMETERS,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.TlsParameters)
  })
_sym_db.RegisterMessage(TlsParameters)

PrivateKeyProvider = _reflection.GeneratedProtocolMessageType('PrivateKeyProvider', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATEKEYPROVIDER,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider)
  })
_sym_db.RegisterMessage(PrivateKeyProvider)

TlsCertificate = _reflection.GeneratedProtocolMessageType('TlsCertificate', (_message.Message,), {
  'DESCRIPTOR' : _TLSCERTIFICATE,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.TlsCertificate)
  })
_sym_db.RegisterMessage(TlsCertificate)

TlsSessionTicketKeys = _reflection.GeneratedProtocolMessageType('TlsSessionTicketKeys', (_message.Message,), {
  'DESCRIPTOR' : _TLSSESSIONTICKETKEYS,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.TlsSessionTicketKeys)
  })
_sym_db.RegisterMessage(TlsSessionTicketKeys)

CertificateValidationContext = _reflection.GeneratedProtocolMessageType('CertificateValidationContext', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATEVALIDATIONCONTEXT,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext)
  })
_sym_db.RegisterMessage(CertificateValidationContext)


DESCRIPTOR._options = None
_TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version']._options = None
_TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version']._options = None
_TLSPARAMETERS._options = None
_PRIVATEKEYPROVIDER.fields_by_name['provider_name']._options = None
_PRIVATEKEYPROVIDER.fields_by_name['typed_config']._options = None
_PRIVATEKEYPROVIDER._options = None
_TLSCERTIFICATE.fields_by_name['private_key']._options = None
_TLSCERTIFICATE.fields_by_name['password']._options = None
_TLSCERTIFICATE._options = None
_TLSSESSIONTICKETKEYS.fields_by_name['keys']._options = None
_TLSSESSIONTICKETKEYS._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_spki']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_hash']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification']._options = None
_CERTIFICATEVALIDATIONCONTEXT._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/starttls/v4alpha/starttls.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.transport_sockets.raw_buffer.v3 import raw_buffer_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_raw__buffer_dot_v3_dot_raw__buffer__pb2
from envoy.extensions.transport_sockets.tls.v4alpha import tls_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_tls__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/starttls/v4alpha/starttls.proto',
  package='envoy.extensions.transport_sockets.starttls.v4alpha',
  syntax='proto3',
  serialized_options=b'\nAio.envoyproxy.envoy.extensions.transport_sockets.starttls.v4alphaB\rStarttlsProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nBenvoy/extensions/transport_sockets/starttls/v4alpha/starttls.proto\x12\x33\x65nvoy.extensions.transport_sockets.starttls.v4alpha\x1a\x41\x65nvoy/extensions/transport_sockets/raw_buffer/v3/raw_buffer.proto\x1a\x38\x65nvoy/extensions/transport_sockets/tls/v4alpha/tls.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9f\x02\n\x0eStartTlsConfig\x12\\\n\x17\x63leartext_socket_config\x18\x01 \x01(\x0b\x32;.envoy.extensions.transport_sockets.raw_buffer.v3.RawBuffer\x12i\n\x11tls_socket_config\x18\x02 \x01(\x0b\x32\x44.envoy.extensions.transport_sockets.tls.v4alpha.DownstreamTlsContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:D\x9a\xc5\x88\x1e?\n=envoy.extensions.transport_sockets.starttls.v3.StartTlsConfigB\\\nAio.envoyproxy.envoy.extensions.transport_sockets.starttls.v4alphaB\rStarttlsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_transport__sockets_dot_raw__buffer_dot_v3_dot_raw__buffer__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_tls__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STARTTLSCONFIG = _descriptor.Descriptor(
  name='StartTlsConfig',
  full_name='envoy.extensions.transport_sockets.starttls.v4alpha.StartTlsConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cleartext_socket_config', full_name='envoy.extensions.transport_sockets.starttls.v4alpha.StartTlsConfig.cleartext_socket_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_socket_config', full_name='envoy.extensions.transport_sockets.starttls.v4alpha.StartTlsConfig.tls_socket_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036?\n=envoy.extensions.transport_sockets.starttls.v3.StartTlsConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=627,
)

_STARTTLSCONFIG.fields_by_name['cleartext_socket_config'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_raw__buffer_dot_v3_dot_raw__buffer__pb2._RAWBUFFER
_STARTTLSCONFIG.fields_by_name['tls_socket_config'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_tls__pb2._DOWNSTREAMTLSCONTEXT
DESCRIPTOR.message_types_by_name['StartTlsConfig'] = _STARTTLSCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StartTlsConfig = _reflection.GeneratedProtocolMessageType('StartTlsConfig', (_message.Message,), {
  'DESCRIPTOR' : _STARTTLSCONFIG,
  '__module__' : 'envoy.extensions.transport_sockets.starttls.v4alpha.starttls_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.starttls.v4alpha.StartTlsConfig)
  })
_sym_db.RegisterMessage(StartTlsConfig)


DESCRIPTOR._options = None
_STARTTLSCONFIG.fields_by_name['tls_socket_config']._options = None
_STARTTLSCONFIG._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/tap/v3/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.common.matcher.v3 import matcher_pb2 as envoy_dot_config_dot_common_dot_matcher_dot_v3_dot_matcher__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/tap/v3/common.proto',
  package='envoy.config.tap.v3',
  syntax='proto3',
  serialized_options=b'\n!io.envoyproxy.envoy.config.tap.v3B\013CommonProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n envoy/config/tap/v3/common.proto\x12\x13\x65nvoy.config.tap.v3\x1a,envoy/config/common/matcher/v3/matcher.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbe\x02\n\tTapConfig\x12=\n\x0cmatch_config\x18\x01 \x01(\x0b\x32#.envoy.config.tap.v3.MatchPredicateB\x02\x18\x01\x12=\n\x05match\x18\x04 \x01(\x0b\x32..envoy.config.common.matcher.v3.MatchPredicate\x12\x42\n\routput_config\x18\x02 \x01(\x0b\x32!.envoy.config.tap.v3.OutputConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x43\n\x0btap_enabled\x18\x03 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent:*\x9a\xc5\x88\x1e%\n#envoy.service.tap.v2alpha.TapConfig\"\x95\x07\n\x0eMatchPredicate\x12@\n\x08or_match\x18\x01 \x01(\x0b\x32,.envoy.config.tap.v3.MatchPredicate.MatchSetH\x00\x12\x41\n\tand_match\x18\x02 \x01(\x0b\x32,.envoy.config.tap.v3.MatchPredicate.MatchSetH\x00\x12\x38\n\tnot_match\x18\x03 \x01(\x0b\x32#.envoy.config.tap.v3.MatchPredicateH\x00\x12\x1c\n\tany_match\x18\x04 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12K\n\x1ahttp_request_headers_match\x18\x05 \x01(\x0b\x32%.envoy.config.tap.v3.HttpHeadersMatchH\x00\x12L\n\x1bhttp_request_trailers_match\x18\x06 \x01(\x0b\x32%.envoy.config.tap.v3.HttpHeadersMatchH\x00\x12L\n\x1bhttp_response_headers_match\x18\x07 \x01(\x0b\x32%.envoy.config.tap.v3.HttpHeadersMatchH\x00\x12M\n\x1chttp_response_trailers_match\x18\x08 \x01(\x0b\x32%.envoy.config.tap.v3.HttpHeadersMatchH\x00\x12T\n\x1fhttp_request_generic_body_match\x18\t \x01(\x0b\x32).envoy.config.tap.v3.HttpGenericBodyMatchH\x00\x12U\n http_response_generic_body_match\x18\n \x01(\x0b\x32).envoy.config.tap.v3.HttpGenericBodyMatchH\x00\x1a\x82\x01\n\x08MatchSet\x12<\n\x05rules\x18\x01 \x03(\x0b\x32#.envoy.config.tap.v3.MatchPredicateB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:8\x9a\xc5\x88\x1e\x33\n1envoy.service.tap.v2alpha.MatchPredicate.MatchSet:/\x9a\xc5\x88\x1e*\n(envoy.service.tap.v2alpha.MatchPredicateB\x0b\n\x04rule\x12\x03\xf8\x42\x01\"|\n\x10HttpHeadersMatch\x12\x35\n\x07headers\x18\x01 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher:1\x9a\xc5\x88\x1e,\n*envoy.service.tap.v2alpha.HttpHeadersMatch\"\xe6\x01\n\x14HttpGenericBodyMatch\x12\x13\n\x0b\x62ytes_limit\x18\x01 \x01(\r\x12V\n\x08patterns\x18\x02 \x03(\x0b\x32:.envoy.config.tap.v3.HttpGenericBodyMatch.GenericTextMatchB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x61\n\x10GenericTextMatch\x12\x1f\n\x0cstring_match\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x1f\n\x0c\x62inary_match\x18\x02 \x01(\x0c\x42\x07\xfa\x42\x04z\x02\x10\x01H\x00\x42\x0b\n\x04rule\x12\x03\xf8\x42\x01\"\x86\x02\n\x0cOutputConfig\x12:\n\x05sinks\x18\x01 \x03(\x0b\x32\x1f.envoy.config.tap.v3.OutputSinkB\n\xfa\x42\x07\x92\x01\x04\x08\x01\x10\x01\x12;\n\x15max_buffered_rx_bytes\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12;\n\x15max_buffered_tx_bytes\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x11\n\tstreaming\x18\x04 \x01(\x08:-\x9a\xc5\x88\x1e(\n&envoy.service.tap.v2alpha.OutputConfig\"\xd7\x03\n\nOutputSink\x12@\n\x06\x66ormat\x18\x01 \x01(\x0e\x32&.envoy.config.tap.v3.OutputSink.FormatB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x42\n\x0fstreaming_admin\x18\x02 \x01(\x0b\x32\'.envoy.config.tap.v3.StreamingAdminSinkH\x00\x12;\n\x0c\x66ile_per_tap\x18\x03 \x01(\x0b\x32#.envoy.config.tap.v3.FilePerTapSinkH\x00\x12@\n\x0estreaming_grpc\x18\x04 \x01(\x0b\x32&.envoy.config.tap.v3.StreamingGrpcSinkH\x00\"~\n\x06\x46ormat\x12\x16\n\x12JSON_BODY_AS_BYTES\x10\x00\x12\x17\n\x13JSON_BODY_AS_STRING\x10\x01\x12\x10\n\x0cPROTO_BINARY\x10\x02\x12!\n\x1dPROTO_BINARY_LENGTH_DELIMITED\x10\x03\x12\x0e\n\nPROTO_TEXT\x10\x04:+\x9a\xc5\x88\x1e&\n$envoy.service.tap.v2alpha.OutputSinkB\x17\n\x10output_sink_type\x12\x03\xf8\x42\x01\"I\n\x12StreamingAdminSink:3\x9a\xc5\x88\x1e.\n,envoy.service.tap.v2alpha.StreamingAdminSink\"_\n\x0e\x46ilePerTapSink\x12\x1c\n\x0bpath_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:/\x9a\xc5\x88\x1e*\n(envoy.service.tap.v2alpha.FilePerTapSink\"\x9a\x01\n\x11StreamingGrpcSink\x12\x0e\n\x06tap_id\x18\x01 \x01(\t\x12\x41\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:2\x9a\xc5\x88\x1e-\n+envoy.service.tap.v2alpha.StreamingGrpcSinkB:\n!io.envoyproxy.envoy.config.tap.v3B\x0b\x43ommonProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_common_dot_matcher_dot_v3_dot_matcher__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_OUTPUTSINK_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='envoy.config.tap.v3.OutputSink.Format',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='JSON_BODY_AS_BYTES', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JSON_BODY_AS_STRING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTO_BINARY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTO_BINARY_LENGTH_DELIMITED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTO_TEXT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2487,
  serialized_end=2613,
)
_sym_db.RegisterEnumDescriptor(_OUTPUTSINK_FORMAT)


_TAPCONFIG = _descriptor.Descriptor(
  name='TapConfig',
  full_name='envoy.config.tap.v3.TapConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_config', full_name='envoy.config.tap.v3.TapConfig.match_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match', full_name='envoy.config.tap.v3.TapConfig.match', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_config', full_name='envoy.config.tap.v3.TapConfig.output_config', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tap_enabled', full_name='envoy.config.tap.v3.TapConfig.tap_enabled', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.service.tap.v2alpha.TapConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=665,
)


_MATCHPREDICATE_MATCHSET = _descriptor.Descriptor(
  name='MatchSet',
  full_name='envoy.config.tap.v3.MatchPredicate.MatchSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.config.tap.v3.MatchPredicate.MatchSet.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.service.tap.v2alpha.MatchPredicate.MatchSet',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1523,
)

_MATCHPREDICATE = _descriptor.Descriptor(
  name='MatchPredicate',
  full_name='envoy.config.tap.v3.MatchPredicate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='or_match', full_name='envoy.config.tap.v3.MatchPredicate.or_match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='and_match', full_name='envoy.config.tap.v3.MatchPredicate.and_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_match', full_name='envoy.config.tap.v3.MatchPredicate.not_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='any_match', full_name='envoy.config.tap.v3.MatchPredicate.any_match', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_request_headers_match', full_name='envoy.config.tap.v3.MatchPredicate.http_request_headers_match', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_request_trailers_match', full_name='envoy.config.tap.v3.MatchPredicate.http_request_trailers_match', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_response_headers_match', full_name='envoy.config.tap.v3.MatchPredicate.http_response_headers_match', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_response_trailers_match', full_name='envoy.config.tap.v3.MatchPredicate.http_response_trailers_match', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_request_generic_body_match', full_name='envoy.config.tap.v3.MatchPredicate.http_request_generic_body_match', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_response_generic_body_match', full_name='envoy.config.tap.v3.MatchPredicate.http_response_generic_body_match', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHPREDICATE_MATCHSET, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.service.tap.v2alpha.MatchPredicate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule', full_name='envoy.config.tap.v3.MatchPredicate.rule',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=668,
  serialized_end=1585,
)


_HTTPHEADERSMATCH = _descriptor.Descriptor(
  name='HttpHeadersMatch',
  full_name='envoy.config.tap.v3.HttpHeadersMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.config.tap.v3.HttpHeadersMatch.headers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.service.tap.v2alpha.HttpHeadersMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1587,
  serialized_end=1711,
)


_HTTPGENERICBODYMATCH_GENERICTEXTMATCH = _descriptor.Descriptor(
  name='GenericTextMatch',
  full_name='envoy.config.tap.v3.HttpGenericBodyMatch.GenericTextMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_match', full_name='envoy.config.tap.v3.HttpGenericBodyMatch.GenericTextMatch.string_match', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_match', full_name='envoy.config.tap.v3.HttpGenericBodyMatch.GenericTextMatch.binary_match', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004z\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule', full_name='envoy.config.tap.v3.HttpGenericBodyMatch.GenericTextMatch.rule',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1847,
  serialized_end=1944,
)

_HTTPGENERICBODYMATCH = _descriptor.Descriptor(
  name='HttpGenericBodyMatch',
  full_name='envoy.config.tap.v3.HttpGenericBodyMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bytes_limit', full_name='envoy.config.tap.v3.HttpGenericBodyMatch.bytes_limit', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patterns', full_name='envoy.config.tap.v3.HttpGenericBodyMatch.patterns', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPGENERICBODYMATCH_GENERICTEXTMATCH, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1714,
  serialized_end=1944,
)


_OUTPUTCONFIG = _descriptor.Descriptor(
  name='OutputConfig',
  full_name='envoy.config.tap.v3.OutputConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sinks', full_name='envoy.config.tap.v3.OutputConfig.sinks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\222\001\004\010\001\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_buffered_rx_bytes', full_name='envoy.config.tap.v3.OutputConfig.max_buffered_rx_bytes', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_buffered_tx_bytes', full_name='envoy.config.tap.v3.OutputConfig.max_buffered_tx_bytes', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streaming', full_name='envoy.config.tap.v3.OutputConfig.streaming', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.service.tap.v2alpha.OutputConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1947,
  serialized_end=2209,
)


_OUTPUTSINK = _descriptor.Descriptor(
  name='OutputSink',
  full_name='envoy.config.tap.v3.OutputSink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='envoy.config.tap.v3.OutputSink.format', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streaming_admin', full_name='envoy.config.tap.v3.OutputSink.streaming_admin', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_per_tap', full_name='envoy.config.tap.v3.OutputSink.file_per_tap', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streaming_grpc', full_name='envoy.config.tap.v3.OutputSink.streaming_grpc', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OUTPUTSINK_FORMAT,
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.service.tap.v2alpha.OutputSink',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='output_sink_type', full_name='envoy.config.tap.v3.OutputSink.output_sink_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2212,
  serialized_end=2683,
)


_STREAMINGADMINSINK = _descriptor.Descriptor(
  name='StreamingAdminSink',
  full_name='envoy.config.tap.v3.StreamingAdminSink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.service.tap.v2alpha.StreamingAdminSink',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2685,
  serialized_end=2758,
)


_FILEPERTAPSINK = _descriptor.Descriptor(
  name='FilePerTapSink',
  full_name='envoy.config.tap.v3.FilePerTapSink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_prefix', full_name='envoy.config.tap.v3.FilePerTapSink.path_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.service.tap.v2alpha.FilePerTapSink',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2760,
  serialized_end=2855,
)


_STREAMINGGRPCSINK = _descriptor.Descriptor(
  name='StreamingGrpcSink',
  full_name='envoy.config.tap.v3.StreamingGrpcSink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tap_id', full_name='envoy.config.tap.v3.StreamingGrpcSink.tap_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.config.tap.v3.StreamingGrpcSink.grpc_service', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.service.tap.v2alpha.StreamingGrpcSink',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2858,
  serialized_end=3012,
)

_TAPCONFIG.fields_by_name['match_config'].message_type = _MATCHPREDICATE
_TAPCONFIG.fields_by_name['match'].message_type = envoy_dot_config_dot_common_dot_matcher_dot_v3_dot_matcher__pb2._MATCHPREDICATE
_TAPCONFIG.fields_by_name['output_config'].message_type = _OUTPUTCONFIG
_TAPCONFIG.fields_by_name['tap_enabled'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_MATCHPREDICATE_MATCHSET.fields_by_name['rules'].message_type = _MATCHPREDICATE
_MATCHPREDICATE_MATCHSET.containing_type = _MATCHPREDICATE
_MATCHPREDICATE.fields_by_name['or_match'].message_type = _MATCHPREDICATE_MATCHSET
_MATCHPREDICATE.fields_by_name['and_match'].message_type = _MATCHPREDICATE_MATCHSET
_MATCHPREDICATE.fields_by_name['not_match'].message_type = _MATCHPREDICATE
_MATCHPREDICATE.fields_by_name['http_request_headers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_request_trailers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_response_headers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_response_trailers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_request_generic_body_match'].message_type = _HTTPGENERICBODYMATCH
_MATCHPREDICATE.fields_by_name['http_response_generic_body_match'].message_type = _HTTPGENERICBODYMATCH
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['or_match'])
_MATCHPREDICATE.fields_by_name['or_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['and_match'])
_MATCHPREDICATE.fields_by_name['and_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['not_match'])
_MATCHPREDICATE.fields_by_name['not_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['any_match'])
_MATCHPREDICATE.fields_by_name['any_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_request_headers_match'])
_MATCHPREDICATE.fields_by_name['http_request_headers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_request_trailers_match'])
_MATCHPREDICATE.fields_by_name['http_request_trailers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_response_headers_match'])
_MATCHPREDICATE.fields_by_name['http_response_headers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_response_trailers_match'])
_MATCHPREDICATE.fields_by_name['http_response_trailers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_request_generic_body_match'])
_MATCHPREDICATE.fields_by_name['http_request_generic_body_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_response_generic_body_match'])
_MATCHPREDICATE.fields_by_name['http_response_generic_body_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_HTTPHEADERSMATCH.fields_by_name['headers'].message_type = envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2._HEADERMATCHER
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.containing_type = _HTTPGENERICBODYMATCH
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule'].fields.append(
  _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['string_match'])
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['string_match'].containing_oneof = _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule']
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule'].fields.append(
  _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['binary_match'])
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['binary_match'].containing_oneof = _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule']
_HTTPGENERICBODYMATCH.fields_by_name['patterns'].message_type = _HTTPGENERICBODYMATCH_GENERICTEXTMATCH
_OUTPUTCONFIG.fields_by_name['sinks'].message_type = _OUTPUTSINK
_OUTPUTCONFIG.fields_by_name['max_buffered_rx_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTPUTCONFIG.fields_by_name['max_buffered_tx_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTPUTSINK.fields_by_name['format'].enum_type = _OUTPUTSINK_FORMAT
_OUTPUTSINK.fields_by_name['streaming_admin'].message_type = _STREAMINGADMINSINK
_OUTPUTSINK.fields_by_name['file_per_tap'].message_type = _FILEPERTAPSINK
_OUTPUTSINK.fields_by_name['streaming_grpc'].message_type = _STREAMINGGRPCSINK
_OUTPUTSINK_FORMAT.containing_type = _OUTPUTSINK
_OUTPUTSINK.oneofs_by_name['output_sink_type'].fields.append(
  _OUTPUTSINK.fields_by_name['streaming_admin'])
_OUTPUTSINK.fields_by_name['streaming_admin'].containing_oneof = _OUTPUTSINK.oneofs_by_name['output_sink_type']
_OUTPUTSINK.oneofs_by_name['output_sink_type'].fields.append(
  _OUTPUTSINK.fields_by_name['file_per_tap'])
_OUTPUTSINK.fields_by_name['file_per_tap'].containing_oneof = _OUTPUTSINK.oneofs_by_name['output_sink_type']
_OUTPUTSINK.oneofs_by_name['output_sink_type'].fields.append(
  _OUTPUTSINK.fields_by_name['streaming_grpc'])
_OUTPUTSINK.fields_by_name['streaming_grpc'].containing_oneof = _OUTPUTSINK.oneofs_by_name['output_sink_type']
_STREAMINGGRPCSINK.fields_by_name['grpc_service'].message_type = envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2._GRPCSERVICE
DESCRIPTOR.message_types_by_name['TapConfig'] = _TAPCONFIG
DESCRIPTOR.message_types_by_name['MatchPredicate'] = _MATCHPREDICATE
DESCRIPTOR.message_types_by_name['HttpHeadersMatch'] = _HTTPHEADERSMATCH
DESCRIPTOR.message_types_by_name['HttpGenericBodyMatch'] = _HTTPGENERICBODYMATCH
DESCRIPTOR.message_types_by_name['OutputConfig'] = _OUTPUTCONFIG
DESCRIPTOR.message_types_by_name['OutputSink'] = _OUTPUTSINK
DESCRIPTOR.message_types_by_name['StreamingAdminSink'] = _STREAMINGADMINSINK
DESCRIPTOR.message_types_by_name['FilePerTapSink'] = _FILEPERTAPSINK
DESCRIPTOR.message_types_by_name['StreamingGrpcSink'] = _STREAMINGGRPCSINK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TapConfig = _reflection.GeneratedProtocolMessageType('TapConfig', (_message.Message,), {
  'DESCRIPTOR' : _TAPCONFIG,
  '__module__' : 'envoy.config.tap.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.tap.v3.TapConfig)
  })
_sym_db.RegisterMessage(TapConfig)

MatchPredicate = _reflection.GeneratedProtocolMessageType('MatchPredicate', (_message.Message,), {

  'MatchSet' : _reflection.GeneratedProtocolMessageType('MatchSet', (_message.Message,), {
    'DESCRIPTOR' : _MATCHPREDICATE_MATCHSET,
    '__module__' : 'envoy.config.tap.v3.common_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.tap.v3.MatchPredicate.MatchSet)
    })
  ,
  'DESCRIPTOR' : _MATCHPREDICATE,
  '__module__' : 'envoy.config.tap.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.tap.v3.MatchPredicate)
  })
_sym_db.RegisterMessage(MatchPredicate)
_sym_db.RegisterMessage(MatchPredicate.MatchSet)

HttpHeadersMatch = _reflection.GeneratedProtocolMessageType('HttpHeadersMatch', (_message.Message,), {
  'DESCRIPTOR' : _HTTPHEADERSMATCH,
  '__module__' : 'envoy.config.tap.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.tap.v3.HttpHeadersMatch)
  })
_sym_db.RegisterMessage(HttpHeadersMatch)

HttpGenericBodyMatch = _reflection.GeneratedProtocolMessageType('HttpGenericBodyMatch', (_message.Message,), {

  'GenericTextMatch' : _reflection.GeneratedProtocolMessageType('GenericTextMatch', (_message.Message,), {
    'DESCRIPTOR' : _HTTPGENERICBODYMATCH_GENERICTEXTMATCH,
    '__module__' : 'envoy.config.tap.v3.common_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.tap.v3.HttpGenericBodyMatch.GenericTextMatch)
    })
  ,
  'DESCRIPTOR' : _HTTPGENERICBODYMATCH,
  '__module__' : 'envoy.config.tap.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.tap.v3.HttpGenericBodyMatch)
  })
_sym_db.RegisterMessage(HttpGenericBodyMatch)
_sym_db.RegisterMessage(HttpGenericBodyMatch.GenericTextMatch)

OutputConfig = _reflection.GeneratedProtocolMessageType('OutputConfig', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUTCONFIG,
  '__module__' : 'envoy.config.tap.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.tap.v3.OutputConfig)
  })
_sym_db.RegisterMessage(OutputConfig)

OutputSink = _reflection.GeneratedProtocolMessageType('OutputSink', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUTSINK,
  '__module__' : 'envoy.config.tap.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.tap.v3.OutputSink)
  })
_sym_db.RegisterMessage(OutputSink)

StreamingAdminSink = _reflection.GeneratedProtocolMessageType('StreamingAdminSink', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGADMINSINK,
  '__module__' : 'envoy.config.tap.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.tap.v3.StreamingAdminSink)
  })
_sym_db.RegisterMessage(StreamingAdminSink)

FilePerTapSink = _reflection.GeneratedProtocolMessageType('FilePerTapSink', (_message.Message,), {
  'DESCRIPTOR' : _FILEPERTAPSINK,
  '__module__' : 'envoy.config.tap.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.tap.v3.FilePerTapSink)
  })
_sym_db.RegisterMessage(FilePerTapSink)

StreamingGrpcSink = _reflection.GeneratedProtocolMessageType('StreamingGrpcSink', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGGRPCSINK,
  '__module__' : 'envoy.config.tap.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.tap.v3.StreamingGrpcSink)
  })
_sym_db.RegisterMessage(StreamingGrpcSink)


DESCRIPTOR._options = None
_TAPCONFIG.fields_by_name['match_config']._options = None
_TAPCONFIG.fields_by_name['output_config']._options = None
_TAPCONFIG._options = None
_MATCHPREDICATE_MATCHSET.fields_by_name['rules']._options = None
_MATCHPREDICATE_MATCHSET._options = None
_MATCHPREDICATE.oneofs_by_name['rule']._options = None
_MATCHPREDICATE.fields_by_name['any_match']._options = None
_MATCHPREDICATE._options = None
_HTTPHEADERSMATCH._options = None
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule']._options = None
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['string_match']._options = None
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['binary_match']._options = None
_HTTPGENERICBODYMATCH.fields_by_name['patterns']._options = None
_OUTPUTCONFIG.fields_by_name['sinks']._options = None
_OUTPUTCONFIG._options = None
_OUTPUTSINK.oneofs_by_name['output_sink_type']._options = None
_OUTPUTSINK.fields_by_name['format']._options = None
_OUTPUTSINK._options = None
_STREAMINGADMINSINK._options = None
_FILEPERTAPSINK.fields_by_name['path_prefix']._options = None
_FILEPERTAPSINK._options = None
_STREAMINGGRPCSINK.fields_by_name['grpc_service']._options = None
_STREAMINGGRPCSINK._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tls/v3/tls.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.extensions.transport_sockets.tls.v3 import common_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2
from envoy.extensions.transport_sockets.tls.v3 import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/tls/v3/tls.proto',
  package='envoy.extensions.transport_sockets.tls.v3',
  syntax='proto3',
  serialized_options=b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\010TlsProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3envoy/extensions/transport_sockets/tls/v3/tls.proto\x12)envoy.extensions.transport_sockets.tls.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/common.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/secret.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x86\x02\n\x12UpstreamTlsContext\x12W\n\x12\x63ommon_tls_context\x18\x01 \x01(\x0b\x32;.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext\x12\x15\n\x03sni\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03(\xff\x01\x12\x1b\n\x13\x61llow_renegotiation\x18\x03 \x01(\x08\x12\x36\n\x10max_session_keys\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.auth.UpstreamTlsContext\"\xb6\x06\n\x14\x44ownstreamTlsContext\x12W\n\x12\x63ommon_tls_context\x18\x01 \x01(\x0b\x32;.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext\x12>\n\x1arequire_client_certificate\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0brequire_sni\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12^\n\x13session_ticket_keys\x18\x04 \x01(\x0b\x32?.envoy.extensions.transport_sockets.tls.v3.TlsSessionTicketKeysH\x00\x12k\n%session_ticket_keys_sds_secret_config\x18\x05 \x01(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfigH\x00\x12.\n$disable_stateless_session_resumption\x18\x07 \x01(\x08H\x00\x12\x44\n\x0fsession_timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x10\xfa\x42\r\xaa\x01\n\x1a\x06\x08\x80\x80\x80\x80\x10\x32\x00\x12v\n\x12ocsp_staple_policy\x18\x08 \x01(\x0e\x32P.envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.OcspStaplePolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"N\n\x10OcspStaplePolicy\x12\x14\n\x10LENIENT_STAPLING\x10\x00\x12\x13\n\x0fSTRICT_STAPLING\x10\x01\x12\x0f\n\x0bMUST_STAPLE\x10\x02:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.auth.DownstreamTlsContextB\x1a\n\x18session_ticket_keys_type\"\x91\x12\n\x10\x43ommonTlsContext\x12L\n\ntls_params\x18\x01 \x01(\x0b\x32\x38.envoy.extensions.transport_sockets.tls.v3.TlsParameters\x12S\n\x10tls_certificates\x18\x02 \x03(\x0b\x32\x39.envoy.extensions.transport_sockets.tls.v3.TlsCertificate\x12p\n\"tls_certificate_sds_secret_configs\x18\x06 \x03(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfigB\x08\xfa\x42\x05\x92\x01\x02\x10\x01\x12}\n$tls_certificate_certificate_provider\x18\t \x01(\x0b\x32O.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProvider\x12\x8e\x01\n-tls_certificate_certificate_provider_instance\x18\x0b \x01(\x0b\x32W.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderInstance\x12\x65\n\x12validation_context\x18\x03 \x01(\x0b\x32G.envoy.extensions.transport_sockets.tls.v3.CertificateValidationContextH\x00\x12j\n$validation_context_sds_secret_config\x18\x07 \x01(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfigH\x00\x12\x87\x01\n\x1b\x63ombined_validation_context\x18\x08 \x01(\x0b\x32`.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CombinedCertificateValidationContextH\x00\x12\x82\x01\n\'validation_context_certificate_provider\x18\n \x01(\x0b\x32O.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderH\x00\x12\x93\x01\n0validation_context_certificate_provider_instance\x18\x0c \x01(\x0b\x32W.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderInstanceH\x00\x12\x16\n\x0e\x61lpn_protocols\x18\x04 \x03(\t\x12\x45\n\x11\x63ustom_handshaker\x18\r \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x1a\x7f\n\x13\x43\x65rtificateProvider\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x42\n\x0ctyped_config\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigH\x00\x42\r\n\x06\x63onfig\x12\x03\xf8\x42\x01\x1aN\n\x1b\x43\x65rtificateProviderInstance\x12\x15\n\rinstance_name\x18\x01 \x01(\t\x12\x18\n\x10\x63\x65rtificate_name\x18\x02 \x01(\t\x1a\xe3\x05\n$CombinedCertificateValidationContext\x12u\n\x1a\x64\x65\x66\x61ult_validation_context\x18\x01 \x01(\x0b\x32G.envoy.extensions.transport_sockets.tls.v3.CertificateValidationContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x94\x01\n$validation_context_sds_secret_config\x18\x02 \x01(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfigB*\xfa\x42\x05\x8a\x01\x02\x10\x01\xf2\x98\xfe\x8f\x05\x1c\x12\x1a\x64ynamic_validation_context\x12\xa4\x01\n\'validation_context_certificate_provider\x18\x03 \x01(\x0b\x32O.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderB\"\xf2\x98\xfe\x8f\x05\x1c\x12\x1a\x64ynamic_validation_context\x12\xb5\x01\n0validation_context_certificate_provider_instance\x18\x04 \x01(\x0b\x32W.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderInstanceB\"\xf2\x98\xfe\x8f\x05\x1c\x12\x1a\x64ynamic_validation_context:N\x9a\xc5\x88\x1eI\nGenvoy.api.v2.auth.CommonTlsContext.CombinedCertificateValidationContext:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.auth.CommonTlsContextB\x19\n\x17validation_context_typeJ\x04\x08\x05\x10\x06\x42M\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\x08TlsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_extension__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_DOWNSTREAMTLSCONTEXT_OCSPSTAPLEPOLICY = _descriptor.EnumDescriptor(
  name='OcspStaplePolicy',
  full_name='envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.OcspStaplePolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LENIENT_STAPLING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRICT_STAPLING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MUST_STAPLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1370,
  serialized_end=1448,
)
_sym_db.RegisterEnumDescriptor(_DOWNSTREAMTLSCONTEXT_OCSPSTAPLEPOLICY)


_UPSTREAMTLSCONTEXT = _descriptor.Descriptor(
  name='UpstreamTlsContext',
  full_name='envoy.extensions.transport_sockets.tls.v3.UpstreamTlsContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_tls_context', full_name='envoy.extensions.transport_sockets.tls.v3.UpstreamTlsContext.common_tls_context', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sni', full_name='envoy.extensions.transport_sockets.tls.v3.UpstreamTlsContext.sni', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003(\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_renegotiation', full_name='envoy.extensions.transport_sockets.tls.v3.UpstreamTlsContext.allow_renegotiation', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_session_keys', full_name='envoy.extensions.transport_sockets.tls.v3.UpstreamTlsContext.max_session_keys', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.api.v2.auth.UpstreamTlsContext',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=698,
)


_DOWNSTREAMTLSCONTEXT = _descriptor.Descriptor(
  name='DownstreamTlsContext',
  full_name='envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_tls_context', full_name='envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.common_tls_context', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_client_certificate', full_name='envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.require_client_certificate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_sni', full_name='envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.require_sni', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_ticket_keys', full_name='envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.session_ticket_keys', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_ticket_keys_sds_secret_config', full_name='envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.session_ticket_keys_sds_secret_config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_stateless_session_resumption', full_name='envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.disable_stateless_session_resumption', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_timeout', full_name='envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.session_timeout', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\252\001\n\032\006\010\200\200\200\200\0202\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocsp_staple_policy', full_name='envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.ocsp_staple_policy', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DOWNSTREAMTLSCONTEXT_OCSPSTAPLEPOLICY,
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.api.v2.auth.DownstreamTlsContext',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='session_ticket_keys_type', full_name='envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.session_ticket_keys_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=701,
  serialized_end=1523,
)


_COMMONTLSCONTEXT_CERTIFICATEPROVIDER = _descriptor.Descriptor(
  name='CertificateProvider',
  full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProvider.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProvider.typed_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProvider.config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2822,
  serialized_end=2949,
)

_COMMONTLSCONTEXT_CERTIFICATEPROVIDERINSTANCE = _descriptor.Descriptor(
  name='CertificateProviderInstance',
  full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_name', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderInstance.instance_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_name', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderInstance.certificate_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2951,
  serialized_end=3029,
)

_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT = _descriptor.Descriptor(
  name='CombinedCertificateValidationContext',
  full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CombinedCertificateValidationContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_validation_context', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CombinedCertificateValidationContext.default_validation_context', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_context_sds_secret_config', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CombinedCertificateValidationContext.validation_context_sds_secret_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001\362\230\376\217\005\034\022\032dynamic_validation_context', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_context_certificate_provider', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CombinedCertificateValidationContext.validation_context_certificate_provider', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\230\376\217\005\034\022\032dynamic_validation_context', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_context_certificate_provider_instance', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CombinedCertificateValidationContext.validation_context_certificate_provider_instance', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\230\376\217\005\034\022\032dynamic_validation_context', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036I\nGenvoy.api.v2.auth.CommonTlsContext.CombinedCertificateValidationContext',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3032,
  serialized_end=3771,
)

_COMMONTLSCONTEXT = _descriptor.Descriptor(
  name='CommonTlsContext',
  full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tls_params', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.tls_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_certificates', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.tls_certificates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_certificate_sds_secret_configs', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.tls_certificate_sds_secret_configs', index=2,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_certificate_certificate_provider', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.tls_certificate_certificate_provider', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_certificate_certificate_provider_instance', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.tls_certificate_certificate_provider_instance', index=4,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_context', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.validation_context', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_context_sds_secret_config', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.validation_context_sds_secret_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='combined_validation_context', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.combined_validation_context', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_context_certificate_provider', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.validation_context_certificate_provider', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_context_certificate_provider_instance', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.validation_context_certificate_provider_instance', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alpn_protocols', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.alpn_protocols', index=10,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_handshaker', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.custom_handshaker', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COMMONTLSCONTEXT_CERTIFICATEPROVIDER, _COMMONTLSCONTEXT_CERTIFICATEPROVIDERINSTANCE, _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.api.v2.auth.CommonTlsContext',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='validation_context_type', full_name='envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.validation_context_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1526,
  serialized_end=3847,
)

_UPSTREAMTLSCONTEXT.fields_by_name['common_tls_context'].message_type = _COMMONTLSCONTEXT
_UPSTREAMTLSCONTEXT.fields_by_name['max_session_keys'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_DOWNSTREAMTLSCONTEXT.fields_by_name['common_tls_context'].message_type = _COMMONTLSCONTEXT
_DOWNSTREAMTLSCONTEXT.fields_by_name['require_client_certificate'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_DOWNSTREAMTLSCONTEXT.fields_by_name['require_sni'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_DOWNSTREAMTLSCONTEXT.fields_by_name['session_ticket_keys'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2._TLSSESSIONTICKETKEYS
_DOWNSTREAMTLSCONTEXT.fields_by_name['session_ticket_keys_sds_secret_config'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2._SDSSECRETCONFIG
_DOWNSTREAMTLSCONTEXT.fields_by_name['session_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DOWNSTREAMTLSCONTEXT.fields_by_name['ocsp_staple_policy'].enum_type = _DOWNSTREAMTLSCONTEXT_OCSPSTAPLEPOLICY
_DOWNSTREAMTLSCONTEXT_OCSPSTAPLEPOLICY.containing_type = _DOWNSTREAMTLSCONTEXT
_DOWNSTREAMTLSCONTEXT.oneofs_by_name['session_ticket_keys_type'].fields.append(
  _DOWNSTREAMTLSCONTEXT.fields_by_name['session_ticket_keys'])
_DOWNSTREAMTLSCONTEXT.fields_by_name['session_ticket_keys'].containing_oneof = _DOWNSTREAMTLSCONTEXT.oneofs_by_name['session_ticket_keys_type']
_DOWNSTREAMTLSCONTEXT.oneofs_by_name['session_ticket_keys_type'].fields.append(
  _DOWNSTREAMTLSCONTEXT.fields_by_name['session_ticket_keys_sds_secret_config'])
_DOWNSTREAMTLSCONTEXT.fields_by_name['session_ticket_keys_sds_secret_config'].containing_oneof = _DOWNSTREAMTLSCONTEXT.oneofs_by_name['session_ticket_keys_type']
_DOWNSTREAMTLSCONTEXT.oneofs_by_name['session_ticket_keys_type'].fields.append(
  _DOWNSTREAMTLSCONTEXT.fields_by_name['disable_stateless_session_resumption'])
_DOWNSTREAMTLSCONTEXT.fields_by_name['disable_stateless_session_resumption'].containing_oneof = _DOWNSTREAMTLSCONTEXT.oneofs_by_name['session_ticket_keys_type']
_COMMONTLSCONTEXT_CERTIFICATEPROVIDER.fields_by_name['typed_config'].message_type = envoy_dot_config_dot_core_dot_v3_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_COMMONTLSCONTEXT_CERTIFICATEPROVIDER.containing_type = _COMMONTLSCONTEXT
_COMMONTLSCONTEXT_CERTIFICATEPROVIDER.oneofs_by_name['config'].fields.append(
  _COMMONTLSCONTEXT_CERTIFICATEPROVIDER.fields_by_name['typed_config'])
_COMMONTLSCONTEXT_CERTIFICATEPROVIDER.fields_by_name['typed_config'].containing_oneof = _COMMONTLSCONTEXT_CERTIFICATEPROVIDER.oneofs_by_name['config']
_COMMONTLSCONTEXT_CERTIFICATEPROVIDERINSTANCE.containing_type = _COMMONTLSCONTEXT
_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['default_validation_context'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2._CERTIFICATEVALIDATIONCONTEXT
_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_sds_secret_config'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2._SDSSECRETCONFIG
_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_certificate_provider'].message_type = _COMMONTLSCONTEXT_CERTIFICATEPROVIDER
_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_certificate_provider_instance'].message_type = _COMMONTLSCONTEXT_CERTIFICATEPROVIDERINSTANCE
_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.containing_type = _COMMONTLSCONTEXT
_COMMONTLSCONTEXT.fields_by_name['tls_params'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2._TLSPARAMETERS
_COMMONTLSCONTEXT.fields_by_name['tls_certificates'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2._TLSCERTIFICATE
_COMMONTLSCONTEXT.fields_by_name['tls_certificate_sds_secret_configs'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2._SDSSECRETCONFIG
_COMMONTLSCONTEXT.fields_by_name['tls_certificate_certificate_provider'].message_type = _COMMONTLSCONTEXT_CERTIFICATEPROVIDER
_COMMONTLSCONTEXT.fields_by_name['tls_certificate_certificate_provider_instance'].message_type = _COMMONTLSCONTEXT_CERTIFICATEPROVIDERINSTANCE
_COMMONTLSCONTEXT.fields_by_name['validation_context'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2._CERTIFICATEVALIDATIONCONTEXT
_COMMONTLSCONTEXT.fields_by_name['validation_context_sds_secret_config'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2._SDSSECRETCONFIG
_COMMONTLSCONTEXT.fields_by_name['combined_validation_context'].message_type = _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT
_COMMONTLSCONTEXT.fields_by_name['validation_context_certificate_provider'].message_type = _COMMONTLSCONTEXT_CERTIFICATEPROVIDER
_COMMONTLSCONTEXT.fields_by_name['validation_context_certificate_provider_instance'].message_type = _COMMONTLSCONTEXT_CERTIFICATEPROVIDERINSTANCE
_COMMONTLSCONTEXT.fields_by_name['custom_handshaker'].message_type = envoy_dot_config_dot_core_dot_v3_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_COMMONTLSCONTEXT.oneofs_by_name['validation_context_type'].fields.append(
  _COMMONTLSCONTEXT.fields_by_name['validation_context'])
_COMMONTLSCONTEXT.fields_by_name['validation_context'].containing_oneof = _COMMONTLSCONTEXT.oneofs_by_name['validation_context_type']
_COMMONTLSCONTEXT.oneofs_by_name['validation_context_type'].fields.append(
  _COMMONTLSCONTEXT.fields_by_name['validation_context_sds_secret_config'])
_COMMONTLSCONTEXT.fields_by_name['validation_context_sds_secret_config'].containing_oneof = _COMMONTLSCONTEXT.oneofs_by_name['validation_context_type']
_COMMONTLSCONTEXT.oneofs_by_name['validation_context_type'].fields.append(
  _COMMONTLSCONTEXT.fields_by_name['combined_validation_context'])
_COMMONTLSCONTEXT.fields_by_name['combined_validation_context'].containing_oneof = _COMMONTLSCONTEXT.oneofs_by_name['validation_context_type']
_COMMONTLSCONTEXT.oneofs_by_name['validation_context_type'].fields.append(
  _COMMONTLSCONTEXT.fields_by_name['validation_context_certificate_provider'])
_COMMONTLSCONTEXT.fields_by_name['validation_context_certificate_provider'].containing_oneof = _COMMONTLSCONTEXT.oneofs_by_name['validation_context_type']
_COMMONTLSCONTEXT.oneofs_by_name['validation_context_type'].fields.append(
  _COMMONTLSCONTEXT.fields_by_name['validation_context_certificate_provider_instance'])
_COMMONTLSCONTEXT.fields_by_name['validation_context_certificate_provider_instance'].containing_oneof = _COMMONTLSCONTEXT.oneofs_by_name['validation_context_type']
DESCRIPTOR.message_types_by_name['UpstreamTlsContext'] = _UPSTREAMTLSCONTEXT
DESCRIPTOR.message_types_by_name['DownstreamTlsContext'] = _DOWNSTREAMTLSCONTEXT
DESCRIPTOR.message_types_by_name['CommonTlsContext'] = _COMMONTLSCONTEXT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UpstreamTlsContext = _reflection.GeneratedProtocolMessageType('UpstreamTlsContext', (_message.Message,), {
  'DESCRIPTOR' : _UPSTREAMTLSCONTEXT,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.tls_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.UpstreamTlsContext)
  })
_sym_db.RegisterMessage(UpstreamTlsContext)

DownstreamTlsContext = _reflection.GeneratedProtocolMessageType('DownstreamTlsContext', (_message.Message,), {
  'DESCRIPTOR' : _DOWNSTREAMTLSCONTEXT,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.tls_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext)
  })
_sym_db.RegisterMessage(DownstreamTlsContext)

CommonTlsContext = _reflection.GeneratedProtocolMessageType('CommonTlsContext', (_message.Message,), {

  'CertificateProvider' : _reflection.GeneratedProtocolMessageType('CertificateProvider', (_message.Message,), {
    'DESCRIPTOR' : _COMMONTLSCONTEXT_CERTIFICATEPROVIDER,
    '__module__' : 'envoy.extensions.transport_sockets.tls.v3.tls_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProvider)
    })
  ,

  'CertificateProviderInstance' : _reflection.GeneratedProtocolMessageType('CertificateProviderInstance', (_message.Message,), {
    'DESCRIPTOR' : _COMMONTLSCONTEXT_CERTIFICATEPROVIDERINSTANCE,
    '__module__' : 'envoy.extensions.transport_sockets.tls.v3.tls_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderInstance)
    })
  ,

  'CombinedCertificateValidationContext' : _reflection.GeneratedProtocolMessageType('CombinedCertificateValidationContext', (_message.Message,), {
    'DESCRIPTOR' : _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT,
    '__module__' : 'envoy.extensions.transport_sockets.tls.v3.tls_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CombinedCertificateValidationContext)
    })
  ,
  'DESCRIPTOR' : _COMMONTLSCONTEXT,
  '__module__' : 'envoy.extensions.transport_sockets.tls.v3.tls_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.tls.v3.CommonTlsContext)
  })
_sym_db.RegisterMessage(CommonTlsContext)
_sym_db.RegisterMessage(CommonTlsContext.CertificateProvider)
_sym_db.RegisterMessage(CommonTlsContext.CertificateProviderInstance)
_sym_db.RegisterMessage(CommonTlsContext.CombinedCertificateValidationContext)


DESCRIPTOR._options = None
_UPSTREAMTLSCONTEXT.fields_by_name['sni']._options = None
_UPSTREAMTLSCONTEXT._options = None
_DOWNSTREAMTLSCONTEXT.fields_by_name['session_timeout']._options = None
_DOWNSTREAMTLSCONTEXT.fields_by_name['ocsp_staple_policy']._options = None
_DOWNSTREAMTLSCONTEXT._options = None
_COMMONTLSCONTEXT_CERTIFICATEPROVIDER.oneofs_by_name['config']._options = None
_COMMONTLSCONTEXT_CERTIFICATEPROVIDER.fields_by_name['name']._options = None
_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['default_validation_context']._options = None
_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_sds_secret_config']._options = None
_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_certificate_provider']._options = None
_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_certificate_provider_instance']._options = None
_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT._options = None
_COMMONTLSCONTEXT.fields_by_name['tls_certificate_sds_secret_configs']._options = None
_COMMONTLSCONTEXT._options = None
# @@protoc_insertion_point(module_scope)
